#
# spec file for package lxappearance
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxappearance
Version:        0.6.3
Release:        1.20
Summary:        It's a desktop-independent theme switcher for GTK+
License:        GPL-2.0-only
Group:          System/GUI/LXDE
URL:            http://www.lxde.org/
Source0:        https://sourceforge.net/projects/lxde/files/LXAppearance/%{name}-%{version}.tar.xz
BuildRequires:  dbus-1-devel
BuildRequires:  dbus-1-glib-devel
BuildRequires:  docbook-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gnome-icon-theme
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libxslt
BuildRequires:  perl
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
Recommends:     %{name}-lang
Recommends:     %{name}-obconf

%description
LXAppearance is part of LXDE project.
It's a desktop-independent theme switcher for GTK+.

%package devel
Summary:        Lxappearance development files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development files to build lxappearance plugins

%lang_package

%prep
%setup -q

%build
%configure \
	--enable-dbus \
    --sysconfdir=%{_sysconfdir}
%make_build

%install
%make_install
# own the pugins dir so that we don't need it
# for each plugin we will install later
mkdir -p %{buildroot}/%{_libdir}/lxappearance/plugins
%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}
%find_lang %{name}

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/ui
%{_datadir}/%{name}/ui/lxappearance.ui
%{_datadir}/%{name}/ui/about.ui
%{_mandir}/man1/%{name}.1%{?ext_man}
%dir %{_libdir}/lxappearance
%dir %{_libdir}/lxappearance/plugins

%files devel
%license COPYING
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/%{name}.h
%{_libdir}/pkgconfig/%{name}.pc

%files lang -f %{name}.lang
%license COPYING

%changelog
* Sat Jul  4 2020 Andreas Stieger <andreas.stieger@gmx.de>
- lxappearance 0.6.3:
  * No longer ignore GTK_RC_FILES
* Sun Dec 25 2016 trcs@gmx.com
- new upstream version 0.6.2
  * Use $XDG_DATA_HOME/themes for themes search, not just
    $HOME/.themes
  * Use $XDG_DATA_HOME/icons for icon theme install, not ~/.icons
  * Substitute the correct GTK+ version in pkgconfig file
  * Fix About dialog for GTK+ 3
  * Fix demo area background for GTK+ 3
  * Add MATE to NotShowIn in desktop entries
  * Translations updates
* Fri Oct 24 2014 trcs@gmx.com
- new upstream version 0.6.1
  * Always save gtkrc files, even with lxsession running
- spec file clean up
* Tue Oct 21 2014 trcs@gmx.com
- new upstream version 0.6.0
  * SF#694 Fix incorrect settings in .config/gtk-3.0/settings.ini:
    should be 0/1, not bools.
  * Enable accessibility modules toggle in GTK+ configuration
  * Add a Keywords line into lxappearance.desktop file
  * Fix 'make distcheck' : data/ui/*.ui should be cleaned
  * Translation updates
* Fri Sep 19 2014 trcs@gmx.com
- new upstream release 0.5.6
  * Change AC_CONFIG_MACRO_DIR to [.] instead of [m4]
  * Add compilation notes into README file
  * Include ~/.gtkrc-2.0.mine first to be able to apply changes from
  * LXAppearance
  * Add 'keyboard_options' frame for future improvements
  * [SF#614]Don't follow symlink ~/.icons/default or we can recurse
  * inheritance
  * Avoid call to g_thread_init() with GLib >= 2.32
  * Use .glade file names and compress them into .ui purging spaces
  * Update Copyright years in the About dialog
  * Fix compilation warnings with --enable-more-warnings
  * Fix compilation warnings with --enable-debug
  * [SF#515] Fix configure --enable-debug
  * [SF#584] Fix crash on installing new cursor theme
  * [SF#498] Fix lxappearanse 0.5.2 gtk3 linking problem
  * [SF#484] Don't reset contents of settings.ini file, only update
  * Fix crash in update_cursor_demo()
  * Update .gitignore file
  * Get rid of unused libtoolize - this is not a library
  * Remove unused xml-purge program
  * Remove po/Makefile.in.in -it's autogenerated
  * Disable setting of custom colors if run without lxsession
  * Fix broken pt_BR.po translation file
  * Include lxappearance.desktop.in into release tarball
  * Translation updates
* Wed Aug 27 2014 trcs@gmx.com
- applied spec-cleaner
* Thu Jan  9 2014 trcs@gmx.com
- new upstream version 0.5.5
  * bug fix release
  * LXAppearance 0.5.5 released: http://blog.lxde.org/?p=1072
  * LXAppearance 0.5.4 released: http://blog.lxde.org/?p=1069
  * LXAppearance 0.5.3 released: http://blog.lxde.org/?p=1067
  * Fixes bug https://bugzilla.novell.com/show_bug.cgi?id=852004
  * Fixes bug https://bugzilla.novell.com/show_bug.cgi?id=841542
* Tue May 29 2012 andrea@opensuse.org
- New upstream version 0.5.2
  * bug fix release
  * translation updates
* Thu Sep 22 2011 andrea.turrini@gmail.com
- fixed typos in lxappearance.spec
* Fri Jul 29 2011 andrea@opensuse.org
- new upstream version 0.5.1
  * translations updates
  * bug fixes: i.e. fix usage of gtk-xft-hintstyle
  * --enable-man is default
* Sun Jul 24 2011 andrea@opensuse.org
- spec file clean up
- recommends lxappearance-obconf plugin
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Sat Oct 23 2010 andrea@opensuse.org
- New upstream version 0.5.0
  * Little fix for gtkrc file generation.
  * added plugins support
  * added colour scheme support
- split out lxappearance-devel subpacakge
* Fri Jul 30 2010 andrea@opensuse.org
- changed group to System/Gui/LXDE
* Tue Apr  6 2010 andrea@opensuse.org
- removed unsopported locales
* Tue Jan 12 2010 andrea@opensuse.org
- new upstream version 0.4.0
  * Replace all Glade-generated code with GtkBuilder
  * Use icon names defined in newer icon naming spec
  * UI adjustment
  * Fix memory leaks and compiler warnings
  * Translation update (23 languages completed)
- removed no more needed desktop icon patch and brp-checks workaround
- removed no more needed gnome-icon-theme dependency
* Tue Dec  8 2009 andrea@opensuse.org
- new upstream version 0.3.0
* Wed Jul  8 2009 andrea@opensuse.org
- new uptream version 0.2.1
* Thu May 21 2009 andrea@opensuse.org
- new package
